@@ -579,7 +579,7 @@ class Manager(object):
             self.engine = sqlalchemy.create_engine(self.database_uri,
                                                    echo=self.options.debug_sql,
                                                    poolclass=SingletonThreadPool,
-                                                   )  # assert_unicode=True
+                                                   connect_args={'check_same_thread': False})  # assert_unicode=True
         except ImportError:
             print('FATAL: Unable to use SQLite. Are you running Python 2.5 - 2.7 ?\n'
                   'Python should normally have SQLite support built in.\n'
