@@ -449,7 +449,9 @@ class Task(object):
     def rerun(self):
         """Immediately re-run the task after execute has completed,
         task can be re-run up to :attr:`.max_reruns` times."""
-        log.info('Plugin %s has requested task to be ran again after execution has completed.' % self.current_plugin)
+        msg = 'Plugin %s has requested task to be ran again after execution has completed.' % self.current_plugin
+        # Only print the first request for a rerun to the info log
+        log.debug(msg) if self._rerun else log.info(msg)
         if self._rerun_count >= self.max_reruns:
             self._rerun = False
             log.info('Task has been re-run %s times already, stopping for now' % self._rerun_count)
